% Destabilizing evolutionary and eco-evolutionary feedbacks drive eco-evo cycles in empirical systems. 
% Michael H. Cortez, Swati Patel, Sebastian J. Schreiber
% Proceedings B of the Royal Society: Biological Sciences
% DOI: 10.1098/rspb.2019.2298

%   Plots long-term dynamics as functions of evolutionary speed for 
%   Becks et al and Duffy et al models

clear all

scrsz = get(0,'ScreenSize');
figure('Position',[1 scrsz(4) scrsz(3)*0.6 scrsz(4)*.6])
format long;
textsize =16;


%% Becks Model - Bifurcation Plot
subplot(231)
hold on

xeq = 0.3377;
yeq = 2.486+2.8;
aeq = 0.777;

load BecksModel.dat
epsilon = BecksModel(1,:);
minxval = BecksModel(2,:);
maxxval = BecksModel(3,:);
maxx = max(maxxval);
minyval = BecksModel(4,:);
maxyval = BecksModel(5,:);
maxy = max(maxyval);
minaval = BecksModel(6,:);
maxaval = BecksModel(7,:);



plot([0.63 epsilon],[xeq minxval]/maxx,'--b','LineWidth',3);
plot([0.63 epsilon],[xeq maxxval]/maxx,'--b','LineWidth',3);
plot([0.63 epsilon],[yeq minyval]/maxy,'-r','LineWidth',3);
plot([0.63 epsilon],[yeq maxyval]/maxy,'-r','LineWidth',3);
plot([0.63 epsilon],[aeq minaval],'-.c','LineWidth',2);
plot([0.63 epsilon],[aeq maxaval],'-.c','LineWidth',2);
plot([0 0.63],[xeq xeq]/maxx,'--b','LineWidth',3);
plot([0 0.63],[yeq yeq]/maxy,'-r','LineWidth',3);
plot([0 0.63],[aeq aeq],'-.c','LineWidth',2);
set(gca,'ycolor','k','FontSize',textsize,'FontWeight','Bold')
set(gca,'Box','on')
xlabel('Speed of Evolution','FontSize',textsize,'FontWeight','Bold')
ylabel('Scaled Density or Trait','FontSize',textsize,'FontWeight','Bold')
ylim([0 1.3])
xlim([0 2])
set(gca,'XTick',[0 1 2],'YTick',[0 0.5 1])
title('A')
text(0.45,1.18,'B','FontSize',textsize)
plot([0.5 0.5],[1.3 1.27],'-k','LineWidth',1)
text(0.95,1.18,'C','FontSize',textsize)
plot([1 1],[1.3 1.27],'-k','LineWidth',1)

%% Becks Model - Stable Dynamics
subplot(232)

    p1 = .1;
    p2 = 1;
    Ni = 160;
    delta = .3;
    m = 0.55e-1;
    lambda = .4;
    Xc = 0.27e-2;
    Kc1 = 8-5.8*p1;
    Kc2 = 2.2;
    rho = 270;
    Xb = 170;
    Kb = .15;
    G = 0.11e-1;
    epsilon = 0.5;

    para=[p1 p2 Ni delta m lambda Xc Kc1 Kc2 rho Xb Kb G epsilon]; 
    tfinal = [];
    resfinal =[];
    x0=[4 0.3 3 3 0.7];
    startx = x0;
    startt = 0;
    options = odeset('RelTol',10^-12);
    tspan = [0 200];
    [tfinal,resfinal] = ode23s(@BecksModel_Equations,tspan,startx,...
        options,para);

hold on
plot(tfinal,resfinal(:,2)/maxx,'--b','LineWidth',2.5);
plot(tfinal,(resfinal(:,3)+resfinal(:,4))/maxy,'-r','LineWidth',2.5);
plot(tfinal,resfinal(:,5),'-.','color','c',...
    'LineWidth',2.5);
set(gca,'ycolor','k','FontSize',textsize,'FontWeight','Bold')
set(gca,'Box','on')
xlabel('Time','FontSize',textsize,'FontWeight','Bold')
ylabel('Scaled Density or Trait','FontSize',textsize,'FontWeight','Bold')
ylim([0 1.3])
xlim(tspan)
set(gca,'XTick',[0 100 200],'YTick',[0 0.5 1])
title('B')

%% Becks Model - Cyclic Dynamics
subplot(233)
    p1 = .1;
    p2 = 1;
    Ni = 160;
    delta = .3;
    m = 0.55e-1;
    lambda = .4;
    Xc = 0.27e-2;
    Kc1 = 8-5.8*p1;
    Kc2 = 2.2;
    rho = 270;
    Xb = 170;
    Kb = .15;
    G = 0.11e-1;
    epsilon = 1;

    para=[p1 p2 Ni delta m lambda Xc Kc1 Kc2 rho Xb Kb G epsilon]; 
    tfinal = [];
    resfinal =[];
    x0=[6 0.3 2.5 2.8 0.7];
    startx = x0;
    startt = 0;
    options = odeset('RelTol',10^-12);
    tspan = [0 800];
    [tfinal,resfinal] = ode23s(@BecksModel_Equations,tspan,startx,...
        options,para);
    tspan = [0 200];
    startx = resfinal(end,:);
    [tfinal,resfinal] = ode23s(@BecksModel_Equations,tspan,startx,...
        options,para);
    

hold on
plot(tfinal,resfinal(:,2)/maxx,'--b','LineWidth',2.5);
plot(tfinal,(resfinal(:,3)+resfinal(:,4))/maxy,'-r','LineWidth',2.5);
plot(tfinal,resfinal(:,5),'-.','color','c',...
    'LineWidth',2.5);
set(gca,'ycolor','k','FontSize',textsize,'FontWeight','Bold')
set(gca,'Box','on')
xlabel('Time','FontSize',textsize,'FontWeight','Bold')
ylabel('Scaled Density or Trait','FontSize',textsize,'FontWeight','Bold')
ylim([0 1.3])
xlim(tspan)
set(gca,'XTick',[0 100 200],'YTick',[0 0.5 1])
title('C')


%% Duffy Model - Bifurcation Diagram
subplot(234)
hold on

xeq = 1.86;
yeq = 0.025;
zeq = 4118;
aeq = 0.655;
beq = 0.1;

load DuffyModel.dat
epsilon = DuffyModel(1,:);
minxval = DuffyModel(2,:);
maxxval = DuffyModel(3,:);
maxx = max(maxxval);
minyval = DuffyModel(4,:);
maxyval = DuffyModel(5,:);
maxy = max(maxyval);
minzval = DuffyModel(6,:);
maxzval = DuffyModel(7,:);
maxz = max(maxzval);
minaval = DuffyModel(8,:);
maxaval = DuffyModel(9,:);
maxa = max(maxaval);
minbval = DuffyModel(10,:);
maxbval = DuffyModel(11,:);
maxb = max(maxbval);

% Cycle amplitudes
semilogx(log10([18.05 epsilon(1:end-1) 687.7]),[xeq minxval(1:end-1) xeq]/maxx,'--b','LineWidth',3);
semilogx(log10([18.05 epsilon(1:end-1) 687.7]),[xeq maxxval(1:end-1) xeq]/maxx,'--b','LineWidth',3);
semilogx(log10([18.05 epsilon(1:end-1) 687.7]),[yeq minyval(1:end-1) yeq]/maxy,'-r','LineWidth',3);
semilogx(log10([18.05 epsilon(1:end-1) 687.7]),[yeq maxyval(1:end-1) yeq]/maxy,'-r','LineWidth',3);
semilogx(log10([18.05 epsilon(1:end-1) 687.7]),[aeq minaval(1:end-1) aeq],'-.c','LineWidth',2);
semilogx(log10([18.05 epsilon(1:end-1) 687.7]),[aeq maxaval(1:end-1) aeq],'-.c','LineWidth',2);
semilogx(log10([18.05 epsilon(1:end-1) 687.7]),[beq minbval(1:end-1) beq],'-.m','LineWidth',2);
semilogx(log10([18.05 epsilon(1:end-1) 687.7]),[beq maxbval(1:end-1) beq],'-.m','LineWidth',2);

% Stable for low epsilon
semilogx(log10([0.1 epsilon(1)]),[xeq xeq]/maxx,'--b','LineWidth',3);
semilogx(log10([0.1 epsilon(1)]),[yeq yeq]/maxy,'-r','LineWidth',3);
semilogx(log10([0.1 epsilon(1)]),[aeq aeq],'-.c','LineWidth',2);
semilogx(log10([0.1 epsilon(1)]),[beq beq],'-.m','LineWidth',2);

% Stable for high epsilon
semilogx(log10([epsilon(end) 5000]),[xeq xeq]/maxx,'--b','LineWidth',3);
semilogx(log10([epsilon(end) 5000]),[yeq yeq]/maxy,'-r','LineWidth',3);
semilogx(log10([epsilon(end) 5000]),[aeq aeq],'-.c','LineWidth',2);
semilogx(log10([epsilon(end) 5000]),[beq beq],'-.m','LineWidth',2);

set(gca,'ycolor','k','FontSize',textsize,'FontWeight','Bold')
set(gca,'Box','on')
xlabel('Speed of Evolution','FontSize',textsize,'FontWeight','Bold')
ylabel('Scaled Density or Trait','FontSize',textsize,'FontWeight','Bold')
ylim([0 1.3])
xlim([0 3.5])
set(gca,'XTick',[-1 0 1 2 3],'YTick',[0 0.5 1],'XTickLabel',[0.1 1 10 100 1000])
title('D')
text(0,1.18,'E','FontSize',textsize)
% semilogx([15 15],[1.3 1.27],'-k','LineWidth',1)
text(2,1.18,'F','FontSize',textsize)
% semilogx([120 120],[1.3 1.27],'-k','LineWidth',1)


%% Duffy Model - Stable Dynamics

subplot(235)
    beta1 = .5*10^(-6);  
    beta2 = 8.5*10^(-6);  
    b1 = 5712.11*beta1+.241;
    b2 = 5712.11*beta2+.241; 
    d = 0.5e-1;  
    ee = .5;  
    f = .75;  
    K = 5;  
    m = .1;  
    n = 0.5e-1;  
    v = 0.5e-1;  
    theta = 9; 
    sigma = 15000;
    epsilon = 1;

    para=[beta1 beta2 b1 b2 d ee f K m n v theta sigma epsilon]; 
    tfinal = [];
    resfinal =[];
    x0=[1.5 .015 4000 0.65 0.1];
    startx = x0;
    startt = 0;
    options = odeset('RelTol',10^-12);
    tspan = [0 200];
    [tfinal,resfinal] = ode23s(@DuffyModel_Equations,tspan,startx,...
        options,para);
    
%     tspan = [0 100];
%     startx = resfinal(end,:);
%     [tfinal,resfinal] = ode23s(@DuffyModel_Equations,tspan,startx,...
%         options,para);
      
hold on
plot(tfinal,resfinal(:,1)/maxx,'--b','LineWidth',2.5);
plot(tfinal,resfinal(:,2)/maxy,'-r','LineWidth',2.5);
plot(tfinal,resfinal(:,4),'-.','color','c',...
    'LineWidth',2.5);
plot(tfinal,resfinal(:,5),'-.','color','m',...
    'LineWidth',2.5);
set(gca,'ycolor','k','FontSize',textsize,'FontWeight','Bold')
set(gca,'Box','on')
xlabel('Time','FontSize',textsize,'FontWeight','Bold')
ylabel('Density or Trait','FontSize',textsize,'FontWeight','Bold')
ylim([0 1.3])
xlim(tspan)
set(gca,'XTick',[0 100 200],'YTick',[0 0.5 1])
title('E')





%% Duffy Model - Cyclic Dynamics

subplot(236)
    beta1 = .5*10^(-6);  
    beta2 = 8.5*10^(-6);  
    b1 = 5712.11*beta1+.241;
    b2 = 5712.11*beta2+.241; 
    d = 0.5e-1;  
    ee = .5;  
    f = .75;  
    K = 5;  
    m = .1;  
    n = 0.5e-1;  
    v = 0.5e-1;  
    theta = 9; 
    sigma = 15000;
    epsilon = 100;

    para=[beta1 beta2 b1 b2 d ee f K m n v theta sigma epsilon]; 
    tfinal = [];
    resfinal =[];
    x0=[1.5 .015 4000 0.65 0.1];
    startx = x0;
    startt = 0;
    options = odeset('RelTol',10^-12);
    tspan = [0 200];
    [tfinal,resfinal] = ode23s(@DuffyModel_Equations,tspan,startx,...
        options,para);
    
    tspan = [0 100];
    startx = resfinal(end,:);
    [tfinal,resfinal] = ode23s(@DuffyModel_Equations,tspan,startx,...
        options,para);
      
hold on
plot(tfinal,resfinal(:,1)/maxx,'--b','LineWidth',2.5);
plot(tfinal,resfinal(:,2)/maxy,'-r','LineWidth',2.5);
plot(tfinal,resfinal(:,4),'-.','color','c',...
    'LineWidth',2.5);
plot(tfinal,resfinal(:,5),'-.','color','m',...
    'LineWidth',2.5);
set(gca,'ycolor','k','FontSize',textsize,'FontWeight','Bold')
set(gca,'Box','on')
xlabel('Time','FontSize',textsize,'FontWeight','Bold')
ylabel('Density or Trait','FontSize',textsize,'FontWeight','Bold')
ylim([0 1.3])
xlim(tspan)
set(gca,'XTick',[0 50 100],'YTick',[0 0.5 1])
title('F')
